import { Component, OnInit, Inject } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from "@angular/forms";
import { HttpClient } from "@angular/common/http";
import { MAT_DIALOG_DATA, MatDialogRef } from "@angular/material/dialog";
import { ToastrService } from "ngx-toastr";
import { ConfigService } from '@services/config.service';

@Component({
  selector: 'app-create-repository-modal',
  templateUrl: './create-repository-modal.component.html',
  styleUrl: './create-repository-modal.component.css'
})
export class CreateRepositoryModalComponent implements OnInit {
  baseUrl: string;
  repositoryForm: FormGroup<any>;
  loading: boolean = false;
  clientRepository: any = null;

  constructor(
    private fb: FormBuilder,
    private http: HttpClient,
    public dialogRef: MatDialogRef<CreateRepositoryModalComponent>,
    private toastService: ToastrService,
    private configService: ConfigService,
    @Inject(MAT_DIALOG_DATA) public data: any
  ) {
    this.baseUrl = this.configService.apiUrl;
    this.clientRepository = this.data?.clientRepository || null;
    this.repositoryForm = this.fb.group({
      name: [null, Validators.required],
    });
  }

  ngOnInit() {
    // El componente se inicializa
  }

  save(): void {
    if (this.repositoryForm.valid) {
      this.loading = true;
      const payload = {
        name: this.repositoryForm.value.name,
        repository: this.clientRepository ? this.clientRepository.id : null
      };

      this.http.post(`${this.baseUrl}/git-repositories`, payload).subscribe({
        next: (response) => {
          this.toastService.success('Repositorio creado correctamente');
          this.dialogRef.close(response);
        },
        error: (error) => {
          this.toastService.error(error.error?.['hydra:description'] || 'Error al crear el repositorio');
          this.loading = false;
        }
      });
    } else {
      this.toastService.error('Por favor, complete todos los campos requeridos');
    }
  }

  close(): void {
    this.dialogRef.close();
  }
} 